# MONS - CommandLine Celeste Mod Manager
**Work In Progress**

[![PyPI](https://img.shields.io/pypi/v/mons.svg)](https://pypi.python.org/pypi/mons)

## Install:
```console
python3 -m pip install mons
```

## Usage:
```console
mons --help
```

**[Everest Website](https://everestapi.github.io/)**

For general feedback and questions ping `@coloursofnoise` on the Celeste Community Discord:

<a href="https://discord.gg/celeste"><img alt="Mt. Celeste Climbing Association" src="https://discordapp.com/api/guilds/403698615446536203/embed.png?style=banner2" /></a>